@@ -1,4 +1,4 @@
-"""Hera is a Python framework for constructing and submitting Argo Workflows.
+"""Hera makes Python code easy to orchestrate on Argo Workflows through native Python integrations.
 
 The main goal of Hera is to make the Argo ecosystem accessible by simplifying
 workflow construction and submission. Hera presents an intuitive Python interface
