@@ -1,7 +1,7 @@
-"""The script module provides the Script class.
+"""The `hera.workflows.script` module provides the Script class.
 
-See https://argoproj.github.io/argo-workflows/workflow-concepts/#script
-for more on scripts.
+See <https://argoproj.github.io/argo-workflows/workflow-concepts/#script>
+for more on scripts in Argo Workflows.
 """
 
 import ast
@@ -138,10 +138,10 @@ class Script(
     ResourceMixin,
     VolumeMountMixin,
 ):
-    """A Script acts as a wrapper around a container.
+    """A Script in Argo Workflows acts as a wrapper around a Container, where you can specify Python code to run through `source`.
 
-    In Hera this defaults to a "python:3.9" image specified by global_config.image, which runs a python source
-    specified by `Script.source`.
+    In Hera, you should aim to use the script decorator, rather than the Script class directly.
+    You will need to refer to the Script class for the kwargs that the decorator can take, but your IDE should give you code completion and type hints.
     """
 
     container_name: Optional[str] = None
@@ -672,14 +672,10 @@ def script(**script_kwargs) -> Callable:
     Note that invoking the function will result in the template associated with the script to be added to the
     workflow context, so users do not have to worry about that.
 
-    Parameters
-    ----------
-    **script_kwargs
-        Keyword arguments to be passed to the Script object.
+    Args:
+        **script_kwargs: Keyword arguments to be passed to the Script object.
 
     Returns:
-    -------
-    Callable
         Function that wraps a given function into a `Script`.
     """
 
