@@ -1,6 +1,6 @@
 """The workflow module provides the Workflow class.
 
-See https://argoproj.github.io/argo-workflows/workflow-concepts/#the-workflow
+See <https://argoproj.github.io/argo-workflows/workflow-concepts/#the-workflow>
 for more on Workflows.
 """
 
